@@ -155,7 +155,7 @@ class DataVolume(NamespacedResource):
 
     def to_dict(self) -> None:
         super().to_dict()
-        if not self.yaml_file:
+        if not self.kind_dict and not self.yaml_file:
             self.res.update({
                 "spec": {
                     "source": {self.source: {"url": self.url}},
